@@ -226,6 +226,15 @@ class TestColorconv(TestCase):
 
         assert_equal(g.shape, (1, 1))
 
+    def test_rgb2grey_contiguous(self):
+        x = np.random.rand(10, 10, 3)
+        assert rgb2grey(x).flags["C_CONTIGUOUS"]
+        assert rgb2grey(x[:5, :5]).flags["C_CONTIGUOUS"]
+
+    def test_rgb2grey_alpha(self):
+        x = np.random.rand(10, 10, 4)
+        assert rgb2grey(x).ndim == 2
+
     def test_rgb2grey_on_grey(self):
         rgb2grey(np.random.rand(5, 5))
 
@@ -439,6 +448,8 @@ def test_gray2rgb():
 
     assert_equal(y.shape, (3, 1, 3))
     assert_equal(y.dtype, x.dtype)
+    assert_equal(y[..., 0], x)
+    assert_equal(y[0, 0, :], [0, 0, 0])
 
     x = np.array([[0, 128, 255]], dtype=np.uint8)
     z = gray2rgb(x)
@@ -454,6 +465,23 @@ def test_gray2rgb_rgb():
     assert_equal(x, y)
 
 
+def test_gray2rgb_alpha():
+    x = np.random.random((5, 5, 4))
+    assert_equal(gray2rgb(x, alpha=None).shape, (5, 5, 4))
+    assert_equal(gray2rgb(x, alpha=False).shape, (5, 5, 3))
+    assert_equal(gray2rgb(x, alpha=True).shape, (5, 5, 4))
+
+    x = np.random.random((5, 5, 3))
+    assert_equal(gray2rgb(x, alpha=None).shape, (5, 5, 3))
+    assert_equal(gray2rgb(x, alpha=False).shape, (5, 5, 3))
+    assert_equal(gray2rgb(x, alpha=True).shape, (5, 5, 4))
+
+    assert_equal(gray2rgb(np.array([[1, 2], [3, 4.]]),
+                          alpha=True)[0, 0, 3], 1)
+    assert_equal(gray2rgb(np.array([[1, 2], [3, 4]], dtype=np.uint8),
+                          alpha=True)[0, 0, 3], 255)
+
+
 if __name__ == "__main__":
     from numpy.testing import run_module_suite
     run_module_suite()
